# Community

## Community Channels

This documentation may not cover all features comprehensively. If you have any questions or suggestions regarding AstrBot or this documentation, please feel free to reach out to us through the community channels below.

### Discord

<https://discord.gg/hAVk6tgV36>

### GitHub

Welcome to submit Issues or Pull Requests:

- [AstrBotDevs/AstrBot](https://github.com/AstrBotDevs/AstrBot)

### Tencent QQ Groups

> - All groups are available to join. If you find that the group size is below the limit, please feel free to join.

- Group 1: 322154837  (2000-member group)
- Group 3: 630166526  (2000-member group)
- Group 4: 1077826412 (1000-member group)
- Group 5: 822130018  (2000-member group)
- Group 6: 753075035  (2000-member group)
- Group 7: 743746109  (500-member  group)
- Group 8: 1030353265 (500-member  group)
- **AstrBot Core Development Group: 975206796** (AstrBot development members are usually active here. Welcome to anyone interested in programming/AI technology~)

## Become an AstrBot Organization Member

We welcome you to join us!
